@@ -56,6 +56,9 @@ class CreateImageModerationAsyncTaskRequest(AbstractModel):
 
     @property
     def CallbackUrl(self):
+        """接收审核信息回调地址，审核过程中产生的所有结果发送至此地址。
+        :rtype: str
+        """
         return self._CallbackUrl
 
     @CallbackUrl.setter
@@ -64,6 +67,9 @@ class CreateImageModerationAsyncTaskRequest(AbstractModel):
 
     @property
     def BizType(self):
+        """该字段表示策略的具体编号，用于接口调度，在内容安全控制台中可配置。若不传入Biztype参数（留空），则代表采用默认的识别策略；传入则会在审核时根据业务场景采取不同的审核策略。<br>备注：Biztype仅为数字、字母与下划线的组合，长度为3-32个字符；不同Biztype关联不同的业务场景与识别能力策略，调用前请确认正确的Biztype。
+        :rtype: str
+        """
         return self._BizType
 
     @BizType.setter
@@ -72,6 +78,9 @@ class CreateImageModerationAsyncTaskRequest(AbstractModel):
 
     @property
     def DataId(self):
+        """该字段表示您为待检测对象分配的数据ID，传入后可方便您对文件进行标识和管理。<br>取值：由英文字母（大小写均可）、数字及四个特殊符号（_，-，@，#）组成，**长度不超过64个字符**。
+        :rtype: str
+        """
         return self._DataId
 
     @DataId.setter
@@ -80,6 +89,9 @@ class CreateImageModerationAsyncTaskRequest(AbstractModel):
 
     @property
     def FileContent(self):
+        """该字段表示待检测图片文件内容的Base64编码，图片**大小不超过10MB**，建议**分辨率不低于256x256**，否则可能会影响识别效果。<br>备注： **该字段与FileUrl必须选择输入其中一个**。
+        :rtype: str
+        """
         return self._FileContent
 
     @FileContent.setter
@@ -88,6 +100,9 @@ class CreateImageModerationAsyncTaskRequest(AbstractModel):
 
     @property
     def FileUrl(self):
+        """该字段表示待检测图片文件的访问链接，图片支持PNG、JPG、JPEG、BMP、GIF、WEBP格式，**大小不超过100MB**，建议**分辨率不低于256x256**；图片下载时间限制为3秒，超过则会返回下载超时；由于网络安全策略，**送审带重定向的链接，可能引起下载失败**，请尽量避免，比如Http返回302状态码的链接，可能导致接口返回ResourceUnavailable.ImageDownloadError。<br>备注：**该字段与FileContent必须选择输入其中一个**。
+        :rtype: str
+        """
         return self._FileUrl
 
     @FileUrl.setter
@@ -96,6 +111,9 @@ class CreateImageModerationAsyncTaskRequest(AbstractModel):
 
     @property
     def Interval(self):
+        """**GIF/长图检测专用**，用于表示GIF截帧频率（每隔多少张图片抽取一帧进行检测），长图则按照长边：短边取整计算要切割的总图数；默认值为0，此时只会检测GIF的第一帧或对长图不进行切分处理。<br>备注：Interval与MaxFrames参数需要组合使用。例如，Interval=3, MaxFrames=400，则代表在检测GIF/长图时，将每间隔2帧检测一次且最多检测400帧。
+        :rtype: int
+        """
         return self._Interval
 
     @Interval.setter
@@ -104,6 +122,9 @@ class CreateImageModerationAsyncTaskRequest(AbstractModel):
 
     @property
     def MaxFrames(self):
+        """**GIF/长图检测专用**，用于标识最大截帧数量；默认值为1，此时只会检测输入GIF的第一帧或对长图不进行切分处理（可能会造成处理超时）。<br>备注：Interval与MaxFrames参数需要组合使用。例如，Interval=3, MaxFrames=400，则代表在检测GIF/长图时，将每间隔2帧检测一次且最多检测400帧。
+        :rtype: int
+        """
         return self._MaxFrames
 
     @MaxFrames.setter
@@ -112,6 +133,9 @@ class CreateImageModerationAsyncTaskRequest(AbstractModel):
 
     @property
     def User(self):
+        """该字段表示待检测对象对应的用户相关信息，若填入则可甄别相应违规风险用户。
+        :rtype: :class:`tencentcloud.ims.v20201229.models.User`
+        """
         return self._User
 
     @User.setter
@@ -120,6 +144,9 @@ class CreateImageModerationAsyncTaskRequest(AbstractModel):
 
     @property
     def Device(self):
+        """该字段表示待检测对象对应的设备相关信息，若填入则可甄别相应违规风险设备。
+        :rtype: :class:`tencentcloud.ims.v20201229.models.Device`
+        """
         return self._Device
 
     @Device.setter
@@ -168,6 +195,9 @@ class CreateImageModerationAsyncTaskResponse(AbstractModel):
 
     @property
     def DataId(self):
+        """该字段用于返回检测对象对应请求参数中的DataId。
+        :rtype: str
+        """
         return self._DataId
 
     @DataId.setter
@@ -176,6 +206,9 @@ class CreateImageModerationAsyncTaskResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -224,6 +257,9 @@ class Device(AbstractModel):
 
     @property
     def Ip(self):
+        """该字段表示业务用户对应设备的IP地址，同时**支持IPv4和IPv6**地址的记录；需要与IpType参数配合使用。
+        :rtype: str
+        """
         return self._Ip
 
     @Ip.setter
@@ -232,6 +268,9 @@ class Device(AbstractModel):
 
     @property
     def Mac(self):
+        """该字段表示业务用户对应的MAC地址，以方便设备识别与管理；其格式与取值与标准MAC地址一致。
+        :rtype: str
+        """
         return self._Mac
 
     @Mac.setter
@@ -240,6 +279,9 @@ class Device(AbstractModel):
 
     @property
     def TokenId(self):
+        """*内测中，敬请期待。*
+        :rtype: str
+        """
         return self._TokenId
 
     @TokenId.setter
@@ -248,6 +290,9 @@ class Device(AbstractModel):
 
     @property
     def DeviceId(self):
+        """*内测中，敬请期待。*
+        :rtype: str
+        """
         return self._DeviceId
 
     @DeviceId.setter
@@ -256,6 +301,9 @@ class Device(AbstractModel):
 
     @property
     def IMEI(self):
+        """该字段表示业务用户对应设备的**IMEI码**（国际移动设备识别码），该识别码可用于识别每一部独立的手机等移动通信设备，方便设备识别与管理。<br>备注：格式为**15-17位纯数字**。
+        :rtype: str
+        """
         return self._IMEI
 
     @IMEI.setter
@@ -264,6 +312,10 @@ class Device(AbstractModel):
 
     @property
     def IDFA(self):
+        """**iOS设备专用**，该字段表示业务用户对应的**IDFA**(广告标识符),这是由苹果公司提供的用于标识用户的广告标识符，由一串16进制的32位数字和字母组成。<br>
+备注：苹果公司自2021年iOS14更新后允许用户手动关闭或者开启IDFA，故此字符串标记有效性可能有所降低。
+        :rtype: str
+        """
         return self._IDFA
 
     @IDFA.setter
@@ -272,6 +324,9 @@ class Device(AbstractModel):
 
     @property
     def IDFV(self):
+        """**iOS设备专用**，该字段表示业务用户对应的**IDFV**(应用开发商标识符),这是由苹果公司提供的用于标注应用开发商的标识符，由一串16进制的32位数字和字母组成，可被用于唯一标识设备。
+        :rtype: str
+        """
         return self._IDFV
 
     @IDFV.setter
@@ -280,6 +335,9 @@ class Device(AbstractModel):
 
     @property
     def IpType(self):
+        """该字段表示记录的IP地址的类型，取值：**0**（代表IPv4地址）、**1**（代表IPv6地址）；需要与IpType参数配合使用。
+        :rtype: int
+        """
         return self._IpType
 
     @IpType.setter
@@ -317,9 +375,9 @@ class ImageModerationRequest(AbstractModel):
         :type BizType: str
         :param _DataId: 该字段表示您为待检测对象分配的数据ID，传入后可方便您对文件进行标识和管理。<br>取值：由英文字母（大小写均可）、数字及四个特殊符号（_，-，@，#）组成，**长度不超过64个字符**。
         :type DataId: str
-        :param _FileContent: 该字段表示待检测图片文件内容的Base64编码，图片Base64编码内容大小不超过10MB，建议**分辨率不低于256x256**，否则可能会影响识别效果。<br>备注： **该字段与FileUrl必须选择输入其中一个**。
+        :param _FileContent: 该字段表示待检测图片文件内容的Base64编码，由于云API对请求包体有大小限制，图片的**Base64编码内容大小不得超过10MB**。<br/>备注：**该字段与FileUrl必须选择输入其中一个**。
         :type FileContent: str
-        :param _FileUrl: 该字段表示待检测图片文件的访问链接。图片支持PNG、JPG、JPEG、BMP、GIF、WEBP格式，且**大小不得超过30MB**，建议**分辨率不低于256x256**。**图片下载时间限制为3秒，超时将进行一次重试，若再次失败，则会返回下载超时**。由于网络安全策略，**送审带重定向的链接**可能引起下载失败，请尽量避免使用返回302或其他非200状态码的HTTP链接，会导致接口返回 ResourceUnavailable.ImageDownloadError 错误。<br>备注：该字段与FileContent必须选择输入其中一个。
+        :param _FileUrl: 该字段表示待检测图片文件的访问链接，URL源图**大小不超过30MB**。<br />备注：该字段与FileContent必须选择输入其中一个。
         :type FileUrl: str
         :param _Interval: **GIF检测专用**，用于表示GIF截帧频率（每隔多少张图片抽取一帧进行检测）；默认值为0，此时只会检测GIF的第一帧或不进行切分处理。<br>备注：Interval与MaxFrames参数需要组合使用。例如，Interval=3, MaxFrames=400，则代表在检测GIF时，将每间隔2帧检测一次且最多检测400帧。
         :type Interval: int
@@ -341,6 +399,9 @@ class ImageModerationRequest(AbstractModel):
 
     @property
     def BizType(self):
+        """该字段表示策略的具体编号，用于接口调度，在内容安全控制台中可配置。若不传入Biztype参数（留空），则代表采用默认的识别策略；传入则会在审核时根据业务场景采取不同的审核策略。<br>备注：Biztype仅为数字、字母与下划线的组合，长度为3-32个字符；不同Biztype关联不同的业务场景与识别能力策略，调用前请确认正确的Biztype。
+        :rtype: str
+        """
         return self._BizType
 
     @BizType.setter
@@ -349,6 +410,9 @@ class ImageModerationRequest(AbstractModel):
 
     @property
     def DataId(self):
+        """该字段表示您为待检测对象分配的数据ID，传入后可方便您对文件进行标识和管理。<br>取值：由英文字母（大小写均可）、数字及四个特殊符号（_，-，@，#）组成，**长度不超过64个字符**。
+        :rtype: str
+        """
         return self._DataId
 
     @DataId.setter
@@ -357,6 +421,9 @@ class ImageModerationRequest(AbstractModel):
 
     @property
     def FileContent(self):
+        """该字段表示待检测图片文件内容的Base64编码，由于云API对请求包体有大小限制，图片的**Base64编码内容大小不得超过10MB**。<br/>备注：**该字段与FileUrl必须选择输入其中一个**。
+        :rtype: str
+        """
         return self._FileContent
 
     @FileContent.setter
@@ -365,6 +432,9 @@ class ImageModerationRequest(AbstractModel):
 
     @property
     def FileUrl(self):
+        """该字段表示待检测图片文件的访问链接，URL源图**大小不超过30MB**。<br />备注：该字段与FileContent必须选择输入其中一个。
+        :rtype: str
+        """
         return self._FileUrl
 
     @FileUrl.setter
@@ -373,6 +443,9 @@ class ImageModerationRequest(AbstractModel):
 
     @property
     def Interval(self):
+        """**GIF检测专用**，用于表示GIF截帧频率（每隔多少张图片抽取一帧进行检测）；默认值为0，此时只会检测GIF的第一帧或不进行切分处理。<br>备注：Interval与MaxFrames参数需要组合使用。例如，Interval=3, MaxFrames=400，则代表在检测GIF时，将每间隔2帧检测一次且最多检测400帧。
+        :rtype: int
+        """
         return self._Interval
 
     @Interval.setter
@@ -381,6 +454,9 @@ class ImageModerationRequest(AbstractModel):
 
     @property
     def MaxFrames(self):
+        """**GIF检测专用**，用于标识最大截帧数量；默认值为1，此时只会检测输入GIF的第一帧不进行切分处理（可能会造成处理超时）。<br>备注：Interval与MaxFrames参数需要组合使用。例如，Interval=3, MaxFrames=400，则代表在检测GIF时，将每间隔2帧检测一次且最多检测400帧。
+        :rtype: int
+        """
         return self._MaxFrames
 
     @MaxFrames.setter
@@ -389,6 +465,9 @@ class ImageModerationRequest(AbstractModel):
 
     @property
     def User(self):
+        """该字段表示待检测对象对应的用户相关信息，若填入则可甄别相应违规风险用户。
+        :rtype: :class:`tencentcloud.ims.v20201229.models.User`
+        """
         return self._User
 
     @User.setter
@@ -397,6 +476,9 @@ class ImageModerationRequest(AbstractModel):
 
     @property
     def Device(self):
+        """该字段表示待检测对象对应的设备相关信息，若填入则可甄别相应违规风险设备。
+        :rtype: :class:`tencentcloud.ims.v20201229.models.Device`
+        """
         return self._Device
 
     @Device.setter
@@ -486,6 +568,9 @@ class ImageModerationResponse(AbstractModel):
 
     @property
     def Suggestion(self):
+        """该字段用于返回Label标签下的后续操作建议。当您获取到判定结果后，返回值表示系统推荐的后续操作；建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Block**：建议屏蔽，**Review** ：建议人工复审，**Pass**：建议通过
+        :rtype: str
+        """
         return self._Suggestion
 
     @Suggestion.setter
@@ -494,6 +579,9 @@ class ImageModerationResponse(AbstractModel):
 
     @property
     def Label(self):
+        """该字段用于返回检测结果（LabelResults）中所对应的**优先级最高的恶意标签**，表示模型推荐的审核结果，建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Normal**：正常，**Porn**：色情，**Abuse**：谩骂，**Ad**：广告；以及其他令人反感、不安全或不适宜的内容类型。
+        :rtype: str
+        """
         return self._Label
 
     @Label.setter
@@ -502,6 +590,9 @@ class ImageModerationResponse(AbstractModel):
 
     @property
     def SubLabel(self):
+        """该字段用于返回检测结果所命中优先级最高的恶意标签下的子标签名称，如：*色情--性行为*；若未命中任何子标签则返回空字符串。
+        :rtype: str
+        """
         return self._SubLabel
 
     @SubLabel.setter
@@ -510,6 +601,9 @@ class ImageModerationResponse(AbstractModel):
 
     @property
     def Score(self):
+        """该字段用于返回当前标签（Label）下的置信度，取值范围：0（**置信度最低**）-100（**置信度最高** ），越高代表图片越有可能属于当前返回的标签；如：*色情 99*，则表明该图片非常有可能属于色情内容；*色情 0*，则表明该图片不属于色情内容。
+        :rtype: int
+        """
         return self._Score
 
     @Score.setter
@@ -518,6 +612,10 @@ class ImageModerationResponse(AbstractModel):
 
     @property
     def LabelResults(self):
+        """该字段用于返回分类模型命中的恶意标签的详细识别结果，包括涉黄、广告等令人反感、不安全或不适宜的内容类型识别结果。
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: list of LabelResult
+        """
         return self._LabelResults
 
     @LabelResults.setter
@@ -526,6 +624,10 @@ class ImageModerationResponse(AbstractModel):
 
     @property
     def ObjectResults(self):
+        """该字段用于返回物体检测模型的详细检测结果；包括：实体、广告台标、二维码等内容命中的标签名称、标签分数、坐标信息、场景识别结果、建议操作等内容审核信息；详细返回值信息可参阅对应的数据结构（ObjectResults）描述。
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: list of ObjectResult
+        """
         return self._ObjectResults
 
     @ObjectResults.setter
@@ -534,6 +636,10 @@ class ImageModerationResponse(AbstractModel):
 
     @property
     def OcrResults(self):
+        """该字段用于返回OCR文本识别的详细检测结果；包括：文本坐标信息、文本识别结果、建议操作等内容审核信息；详细返回值信息可参阅对应的数据结构（OcrResults）描述。
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: list of OcrResult
+        """
         return self._OcrResults
 
     @OcrResults.setter
@@ -542,6 +648,10 @@ class ImageModerationResponse(AbstractModel):
 
     @property
     def LibResults(self):
+        """该字段用于返回基于图片风险库（风险黑库与正常白库）识别的结果,详细返回值信息可参阅对应的数据结构（LibResults）描述。<br>备注：图片风险库目前**暂不支持自定义库**。
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: list of LibResult
+        """
         return self._LibResults
 
     @LibResults.setter
@@ -550,6 +660,9 @@ class ImageModerationResponse(AbstractModel):
 
     @property
     def DataId(self):
+        """该字段用于返回检测对象对应请求参数中的DataId。
+        :rtype: str
+        """
         return self._DataId
 
     @DataId.setter
@@ -558,6 +671,9 @@ class ImageModerationResponse(AbstractModel):
 
     @property
     def BizType(self):
+        """该字段用于返回检测对象对应请求参数中的BizType。
+        :rtype: str
+        """
         return self._BizType
 
     @BizType.setter
@@ -566,6 +682,10 @@ class ImageModerationResponse(AbstractModel):
 
     @property
     def Extra(self):
+        """该字段用于返回根据您的需求配置的额外附加信息（Extra），如未配置则默认返回值为空。<br>备注：不同客户或Biztype下返回信息不同，如需配置该字段请提交工单咨询或联系售后专员处理。
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Extra
 
     @Extra.setter
@@ -574,6 +694,9 @@ class ImageModerationResponse(AbstractModel):
 
     @property
     def FileMD5(self):
+        """该字段用于返回检测对象对应的MD5校验值，以方便校验文件完整性。
+        :rtype: str
+        """
         return self._FileMD5
 
     @FileMD5.setter
@@ -582,6 +705,10 @@ class ImageModerationResponse(AbstractModel):
 
     @property
     def RecognitionResults(self):
+        """该字段用于返回仅识别图片元素的模型结果；包括：场景模型命中的标签、置信度和位置信息
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: list of RecognitionResult
+        """
         return self._RecognitionResults
 
     @RecognitionResults.setter
@@ -590,6 +717,9 @@ class ImageModerationResponse(AbstractModel):
 
     @property
     def RequestId(self):
+        """唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :rtype: str
+        """
         return self._RequestId
 
     @RequestId.setter
@@ -662,6 +792,10 @@ class LabelDetailItem(AbstractModel):
 
     @property
     def Id(self):
+        """该字段用于返回识别对象的ID以方便识别和区分。
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: int
+        """
         return self._Id
 
     @Id.setter
@@ -670,6 +804,10 @@ class LabelDetailItem(AbstractModel):
 
     @property
     def Name(self):
+        """该字段用于返回识命中的子标签名称。
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Name
 
     @Name.setter
@@ -678,6 +816,10 @@ class LabelDetailItem(AbstractModel):
 
     @property
     def Score(self):
+        """该字段用于返回对应子标签命中的分值，取值为**0-100**，如：*Porn-SexBehavior 99* 则代表相应识别内容命中色情-性行为标签的分值为99。
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: int
+        """
         return self._Score
 
     @Score.setter
@@ -729,6 +871,9 @@ class LabelResult(AbstractModel):
 
     @property
     def Scene(self):
+        """该字段用于返回模型识别出的场景结果，如广告、色情、有害内容等场景。
+        :rtype: str
+        """
         return self._Scene
 
     @Scene.setter
@@ -737,6 +882,9 @@ class LabelResult(AbstractModel):
 
     @property
     def Suggestion(self):
+        """该字段用于返回针对当前恶意标签的后续操作建议。当您获取到判定结果后，返回值表示系统推荐的后续操作；建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Block**：建议屏蔽，**Review** ：建议人工复审，**Pass**：建议通过
+        :rtype: str
+        """
         return self._Suggestion
 
     @Suggestion.setter
@@ -745,6 +893,9 @@ class LabelResult(AbstractModel):
 
     @property
     def Label(self):
+        """该字段用于返回检测结果所对应的恶意标签。<br>返回值：**Normal**：正常，**Porn**：色情，**Abuse**：谩骂，**Ad**：广告；以及其他令人反感、不安全或不适宜的内容类型。
+        :rtype: str
+        """
         return self._Label
 
     @Label.setter
@@ -753,6 +904,9 @@ class LabelResult(AbstractModel):
 
     @property
     def SubLabel(self):
+        """该字段用于返回对应恶意标签下的子标签的检测结果，如：*Porn-SexBehavior*等子标签。
+        :rtype: str
+        """
         return self._SubLabel
 
     @SubLabel.setter
@@ -761,6 +915,9 @@ class LabelResult(AbstractModel):
 
     @property
     def Score(self):
+        """该字段用于返回当前标签（Label）下的置信度，取值范围：0（**置信度最低**）-100（**置信度最高** ），越高代表图片越有可能属于当前返回的标签；如：*色情 99*，则表明该图片非常有可能属于色情内容；*色情 0*，则表明该图片不属于色情内容。
+        :rtype: int
+        """
         return self._Score
 
     @Score.setter
@@ -769,6 +926,10 @@ class LabelResult(AbstractModel):
 
     @property
     def Details(self):
+        """该字段用于返回分类模型命中子标签的详细信息，如：序号、命中标签名称、分数等信息。
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: list of LabelDetailItem
+        """
         return self._Details
 
     @Details.setter
@@ -832,6 +993,9 @@ class LibDetail(AbstractModel):
 
     @property
     def Id(self):
+        """该字段用于返回识别对象的ID以方便识别和区分。
+        :rtype: int
+        """
         return self._Id
 
     @Id.setter
@@ -840,6 +1004,9 @@ class LibDetail(AbstractModel):
 
     @property
     def LibId(self):
+        """该字段用于返回自定义库的ID，以方便自定义库管理和配置。
+        :rtype: str
+        """
         return self._LibId
 
     @LibId.setter
@@ -848,6 +1015,10 @@ class LibDetail(AbstractModel):
 
     @property
     def LibName(self):
+        """该字段用于返回自定义库的名称,以方便自定义库管理和配置。
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._LibName
 
     @LibName.setter
@@ -856,6 +1027,9 @@ class LibDetail(AbstractModel):
 
     @property
     def ImageId(self):
+        """该字段用于返回识别图像对象的ID以方便文件管理。
+        :rtype: str
+        """
         return self._ImageId
 
     @ImageId.setter
@@ -864,6 +1038,9 @@ class LibDetail(AbstractModel):
 
     @property
     def Label(self):
+        """该字段用于返回检测结果所对应的恶意标签。<br>返回值：**Normal**：正常，**Porn**：色情，**Abuse**：谩骂，**Ad**：广告；以及其他令人反感、不安全或不适宜的内容类型。
+        :rtype: str
+        """
         return self._Label
 
     @Label.setter
@@ -872,6 +1049,10 @@ class LibDetail(AbstractModel):
 
     @property
     def Tag(self):
+        """该字段用于返回其他自定义标签以满足您的定制化场景需求，若无需求则可略过。
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Tag
 
     @Tag.setter
@@ -880,6 +1061,9 @@ class LibDetail(AbstractModel):
 
     @property
     def Score(self):
+        """该字段用于返回对应模型命中的分值，取值为**0-100**，如：*Porn 99* 则代表相应识别内容命中色情标签的分值为99。
+        :rtype: int
+        """
         return self._Score
 
     @Score.setter
@@ -936,6 +1120,9 @@ class LibResult(AbstractModel):
 
     @property
     def Scene(self):
+        """该字段表示模型的场景识别结果，默认取值为Similar。
+        :rtype: str
+        """
         return self._Scene
 
     @Scene.setter
@@ -944,6 +1131,9 @@ class LibResult(AbstractModel):
 
     @property
     def Suggestion(self):
+        """该字段用于返回后续操作建议。当您获取到判定结果后，返回值表示系统推荐的后续操作；建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Block**：建议屏蔽，**Review** ：建议人工复审，**Pass**：建议通过
+        :rtype: str
+        """
         return self._Suggestion
 
     @Suggestion.setter
@@ -952,6 +1142,9 @@ class LibResult(AbstractModel):
 
     @property
     def Label(self):
+        """该字段用于返回检测结果所对应的恶意标签。<br>返回值：**Normal**：正常，**Porn**：色情，**Abuse**：谩骂，**Ad**：广告；以及其他令人反感、不安全或不适宜的内容类型。
+        :rtype: str
+        """
         return self._Label
 
     @Label.setter
@@ -960,6 +1153,10 @@ class LibResult(AbstractModel):
 
     @property
     def SubLabel(self):
+        """该字段用于返回恶意标签下对应的子标签的检测结果，如：*Porn-SexBehavior*等子标签。
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._SubLabel
 
     @SubLabel.setter
@@ -968,6 +1165,9 @@ class LibResult(AbstractModel):
 
     @property
     def Score(self):
+        """该字段用于返回图片检索模型识别的分值，取值为**0-100**，表示该审核图片**与库中样本的相似分值**，得分越高，代表当前内容越有可能命中相似图库内的样本。
+        :rtype: int
+        """
         return self._Score
 
     @Score.setter
@@ -976,6 +1176,10 @@ class LibResult(AbstractModel):
 
     @property
     def Details(self):
+        """该字段用于返回黑白库比对结果的详细信息，如：序号、库名称、恶意标签等信息；详细返回信息敬请参考对应数据结构（[LibDetail](https://cloud.tencent.com/document/product/1125/53274#LibDetail)）的描述文档
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: list of LibDetail
+        """
         return self._Details
 
     @Details.setter
@@ -1031,6 +1235,9 @@ class Location(AbstractModel):
 
     @property
     def X(self):
+        """该参数用于返回检测框**左上角位置的横坐标**（x）所在的像素位置，结合剩余参数可唯一确定检测框的大小和位置。
+        :rtype: float
+        """
         return self._X
 
     @X.setter
@@ -1039,6 +1246,9 @@ class Location(AbstractModel):
 
     @property
     def Y(self):
+        """该参数用于返回检测框**左上角位置的纵坐标**（y）所在的像素位置，结合剩余参数可唯一确定检测框的大小和位置。
+        :rtype: float
+        """
         return self._Y
 
     @Y.setter
@@ -1047,6 +1257,9 @@ class Location(AbstractModel):
 
     @property
     def Width(self):
+        """该参数用于返回**检测框的宽度**（由左上角出发在x轴向右延伸的长度），结合剩余参数可唯一确定检测框的大小和位置。
+        :rtype: float
+        """
         return self._Width
 
     @Width.setter
@@ -1055,6 +1268,9 @@ class Location(AbstractModel):
 
     @property
     def Height(self):
+        """该参数用于返回**检测框的高度**（由左上角出发在y轴向下延伸的长度），结合剩余参数可唯一确定检测框的大小和位置。
+        :rtype: float
+        """
         return self._Height
 
     @Height.setter
@@ -1063,6 +1279,9 @@ class Location(AbstractModel):
 
     @property
     def Rotate(self):
+        """该参数用于返回**检测框的旋转角度**，该参数结合X和Y两个坐标参数可唯一确定检测框的具体位置；取值：**0-360**（**角度制**），方向为**逆时针旋转**。
+        :rtype: float
+        """
         return self._Rotate
 
     @Rotate.setter
@@ -1119,6 +1338,9 @@ class ObjectDetail(AbstractModel):
 
     @property
     def Id(self):
+        """该参数用于返回识别对象的ID以方便识别和区分。
+        :rtype: int
+        """
         return self._Id
 
     @Id.setter
@@ -1127,6 +1349,9 @@ class ObjectDetail(AbstractModel):
 
     @property
     def Name(self):
+        """该参数用于返回命中的实体标签。
+        :rtype: str
+        """
         return self._Name
 
     @Name.setter
@@ -1135,6 +1360,9 @@ class ObjectDetail(AbstractModel):
 
     @property
     def Value(self):
+        """该参数用于返回对应实体标签所对应的值或内容。如：当标签为*二维码(QrCode)*时，该字段为识别出的二维码对应的URL地址。
+        :rtype: str
+        """
         return self._Value
 
     @Value.setter
@@ -1143,6 +1371,9 @@ class ObjectDetail(AbstractModel):
 
     @property
     def Score(self):
+        """该参数用于返回对应实体标签命中的分值，取值为**0-100**，如：*QrCode 99* 则代表相应识别内容命中二维码场景标签的概率非常高。
+        :rtype: int
+        """
         return self._Score
 
     @Score.setter
@@ -1151,6 +1382,9 @@ class ObjectDetail(AbstractModel):
 
     @property
     def Location(self):
+        """该字段用于返回实体检测框的坐标位置（左上角xy坐标、长宽、旋转角度）以方便快速定位实体的相关信息。
+        :rtype: :class:`tencentcloud.ims.v20201229.models.Location`
+        """
         return self._Location
 
     @Location.setter
@@ -1159,6 +1393,9 @@ class ObjectDetail(AbstractModel):
 
     @property
     def SubLabel(self):
+        """该参数用于返回命中的实体二级标签。
+        :rtype: str
+        """
         return self._SubLabel
 
     @SubLabel.setter
@@ -1167,6 +1404,10 @@ class ObjectDetail(AbstractModel):
 
     @property
     def ObjectId(self):
+        """该参数用于返回命中的人脸id
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._ObjectId
 
     @ObjectId.setter
@@ -1229,6 +1470,9 @@ class ObjectResult(AbstractModel):
 
     @property
     def Scene(self):
+        """该字段用于返回实体识别出的实体场景结果，如二维码、logo、图片OCR等场景。
+        :rtype: str
+        """
         return self._Scene
 
     @Scene.setter
@@ -1237,6 +1481,9 @@ class ObjectResult(AbstractModel):
 
     @property
     def Suggestion(self):
+        """该字段用于返回针对当前恶意标签的后续操作建议。当您获取到判定结果后，返回值表示系统推荐的后续操作；建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Block**：建议屏蔽，**Review** ：建议人工复审，**Pass**：建议通过
+        :rtype: str
+        """
         return self._Suggestion
 
     @Suggestion.setter
@@ -1245,6 +1492,9 @@ class ObjectResult(AbstractModel):
 
     @property
     def Label(self):
+        """该字段用于返回检测结果所对应的恶意标签，表示模型推荐的审核结果，建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Normal**：正常，**Porn**：色情，**Abuse**：谩骂，**Ad**：广告；以及其他令人反感、不安全或不适宜的内容类型。
+        :rtype: str
+        """
         return self._Label
 
     @Label.setter
@@ -1253,6 +1503,9 @@ class ObjectResult(AbstractModel):
 
     @property
     def SubLabel(self):
+        """该字段用于返回当前恶意标签下对应的子标签的检测结果，如：*Porn-SexBehavior* 等子标签。
+        :rtype: str
+        """
         return self._SubLabel
 
     @SubLabel.setter
@@ -1261,6 +1514,9 @@ class ObjectResult(AbstractModel):
 
     @property
     def Score(self):
+        """该字段用于返回命中当前恶意标签下子标签的分值，取值为**0-100**，如：*Porn-SexBehavior 99* 则代表相应识别内容命中色情-性行为标签的分值为99。
+        :rtype: int
+        """
         return self._Score
 
     @Score.setter
@@ -1269,6 +1525,10 @@ class ObjectResult(AbstractModel):
 
     @property
     def Names(self):
+        """该标签用于返回所识别出的实体名称。
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: list of str
+        """
         return self._Names
 
     @Names.setter
@@ -1277,6 +1537,11 @@ class ObjectResult(AbstractModel):
 
     @property
     def Details(self):
+        """该标签用于返回所识别出实体的详细信息，如：序号、命中标签名称、位置坐标等信息，详细返回内容敬请参考相应数据结构（[ObjectDetail
+](https://cloud.tencent.com/document/api/1125/53274#ObjectDetail)）。
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: list of ObjectDetail
+        """
         return self._Details
 
     @Details.setter
@@ -1340,6 +1605,9 @@ class OcrResult(AbstractModel):
 
     @property
     def Scene(self):
+        """该字段表示识别场景，取值默认为OCR（图片OCR识别）。
+        :rtype: str
+        """
         return self._Scene
 
     @Scene.setter
@@ -1348,6 +1616,9 @@ class OcrResult(AbstractModel):
 
     @property
     def Suggestion(self):
+        """该字段用于返回优先级最高的恶意标签对应的后续操作建议。当您获取到判定结果后，返回值表示系统推荐的后续操作；建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Block**：建议屏蔽，**Review** ：建议人工复审，**Pass**：建议通过
+        :rtype: str
+        """
         return self._Suggestion
 
     @Suggestion.setter
@@ -1356,6 +1627,9 @@ class OcrResult(AbstractModel):
 
     @property
     def Label(self):
+        """该字段用于返回OCR检测结果所对应的优先级最高的恶意标签，表示模型推荐的审核结果，建议您按照业务所需，对不同违规类型与建议值进行处理。<br>返回值：**Normal**：正常，**Porn**：色情，**Abuse**：谩骂，**Ad**：广告；以及其他令人反感、不安全或不适宜的内容类型。
+        :rtype: str
+        """
         return self._Label
 
     @Label.setter
@@ -1364,6 +1638,9 @@ class OcrResult(AbstractModel):
 
     @property
     def SubLabel(self):
+        """该字段用于返回当前标签（Label）下对应的子标签的检测结果，如：*Porn-SexBehavior*等子标签。
+        :rtype: str
+        """
         return self._SubLabel
 
     @SubLabel.setter
@@ -1372,6 +1649,9 @@ class OcrResult(AbstractModel):
 
     @property
     def Score(self):
+        """该字段用于返回当前标签（Label）下的置信度，取值范围：0（**置信度最低**）-100（**置信度最高** ），越高代表文本越有可能属于当前返回的标签；如：*色情 99*，则表明该文本非常有可能属于色情内容；*色情 0*，则表明该文本不属于色情内容。
+        :rtype: int
+        """
         return self._Score
 
     @Score.setter
@@ -1380,6 +1660,10 @@ class OcrResult(AbstractModel):
 
     @property
     def Details(self):
+        """该字段用于返回OCR识别出的结果的详细内容，如：文本内容、对应标签、识别框位置等信息。
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: list of OcrTextDetail
+        """
         return self._Details
 
     @Details.setter
@@ -1388,6 +1672,9 @@ class OcrResult(AbstractModel):
 
     @property
     def Text(self):
+        """该字段用于返回OCR识别出的文字信息。
+        :rtype: str
+        """
         return self._Text
 
     @Text.setter
@@ -1456,6 +1743,9 @@ class OcrTextDetail(AbstractModel):
 
     @property
     def Text(self):
+        """该字段用于返回OCR识别出的文本内容。<br>备注：OCR文本识别上限在**5000字节内**。
+        :rtype: str
+        """
         return self._Text
 
     @Text.setter
@@ -1464,6 +1754,9 @@ class OcrTextDetail(AbstractModel):
 
     @property
     def Label(self):
+        """该字段用于返回检测结果所对应的恶意标签。<br>返回值：**Normal**：正常，**Porn**：色情，**Abuse**：谩骂，**Ad**：广告；以及其他令人反感、不安全或不适宜的内容类型。
+        :rtype: str
+        """
         return self._Label
 
     @Label.setter
@@ -1472,6 +1765,9 @@ class OcrTextDetail(AbstractModel):
 
     @property
     def LibId(self):
+        """该字段用于返回自定义库的ID，以方便自定义库管理和配置。
+        :rtype: str
+        """
         return self._LibId
 
     @LibId.setter
@@ -1480,6 +1776,9 @@ class OcrTextDetail(AbstractModel):
 
     @property
     def LibName(self):
+        """该字段用于返回自定义库的名称，以方便自定义库管理和配置。
+        :rtype: str
+        """
         return self._LibName
 
     @LibName.setter
@@ -1488,6 +1787,9 @@ class OcrTextDetail(AbstractModel):
 
     @property
     def Keywords(self):
+        """该参数用于返回在当前label下命中的关键词。
+        :rtype: list of str
+        """
         return self._Keywords
 
     @Keywords.setter
@@ -1496,6 +1798,9 @@ class OcrTextDetail(AbstractModel):
 
     @property
     def Score(self):
+        """该参数用于返回在当前恶意标签下模型命中的分值，取值为**0-100**；分数越高，代表当前场景越符合该恶意标签所对应的场景。
+        :rtype: int
+        """
         return self._Score
 
     @Score.setter
@@ -1504,6 +1809,9 @@ class OcrTextDetail(AbstractModel):
 
     @property
     def Location(self):
+        """该参数用于返回OCR检测框在图片中的位置（左上角xy坐标、长宽、旋转角度），以方便快速定位识别文字的相关信息。
+        :rtype: :class:`tencentcloud.ims.v20201229.models.Location`
+        """
         return self._Location
 
     @Location.setter
@@ -1512,6 +1820,9 @@ class OcrTextDetail(AbstractModel):
 
     @property
     def Rate(self):
+        """该参数用于返回OCR文本识别结果的置信度，取值在**0**（**置信度最低**）-**100**（**置信度最高**），越高代表对应图像越有可能是识别出的文字；如：*你好 99*，则表明OCR识别框内的文字大概率是”你好“。
+        :rtype: int
+        """
         return self._Rate
 
     @Rate.setter
@@ -1520,6 +1831,9 @@ class OcrTextDetail(AbstractModel):
 
     @property
     def SubLabel(self):
+        """该字段用于返回检测结果所对应的恶意二级标签。
+        :rtype: str
+        """
         return self._SubLabel
 
     @SubLabel.setter
@@ -1568,6 +1882,10 @@ class RecognitionResult(AbstractModel):
 
     @property
     def Label(self):
+        """当前可能的取值：Scene（图片场景模型）
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Label
 
     @Label.setter
@@ -1576,6 +1894,10 @@ class RecognitionResult(AbstractModel):
 
     @property
     def Tags(self):
+        """Label对应模型下的识别标签信息
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: list of RecognitionTag
+        """
         return self._Tags
 
     @Tags.setter
@@ -1624,6 +1946,10 @@ class RecognitionTag(AbstractModel):
 
     @property
     def Name(self):
+        """标签名称
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: str
+        """
         return self._Name
 
     @Name.setter
@@ -1632,6 +1958,10 @@ class RecognitionTag(AbstractModel):
 
     @property
     def Score(self):
+        """置信分：0～100，数值越大表示置信度越高
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: int
+        """
         return self._Score
 
     @Score.setter
@@ -1640,6 +1970,10 @@ class RecognitionTag(AbstractModel):
 
     @property
     def Location(self):
+        """标签位置信息，若模型无位置信息，则可能为零值
+注意：此字段可能返回 null，表示取不到有效值。
+        :rtype: :class:`tencentcloud.ims.v20201229.models.Location`
+        """
         return self._Location
 
     @Location.setter
@@ -1707,6 +2041,10 @@ class User(AbstractModel):
 
     @property
     def UserId(self):
+        """该字段表示业务用户ID,填写后，系统可根据账号过往违规历史优化审核结果判定，有利于存在可疑违规风险时的辅助判断。<br>
+备注：该字段可传入微信openid、QQopenid、字符串等账号信息，与账号类别参数（AccountType）配合使用可确定唯一账号。
+        :rtype: str
+        """
         return self._UserId
 
     @UserId.setter
@@ -1715,6 +2053,9 @@ class User(AbstractModel):
 
     @property
     def Nickname(self):
+        """该字段表示业务用户对应的账号昵称信息。
+        :rtype: str
+        """
         return self._Nickname
 
     @Nickname.setter
@@ -1723,6 +2064,10 @@ class User(AbstractModel):
 
     @property
     def AccountType(self):
+        """该字段表示业务用户ID对应的账号类型，取值：**1**-微信uin，**2**-QQ号，**3**-微信群uin，**4**-qq群号，**5**-微信openid，**6**-QQopenid，**7**-其它string。<br>
+该字段与账号ID参数（UserId）配合使用可确定唯一账号。
+        :rtype: str
+        """
         return self._AccountType
 
     @AccountType.setter
@@ -1731,6 +2076,10 @@ class User(AbstractModel):
 
     @property
     def Gender(self):
+        """该字段表示业务用户对应账号的性别信息。<br>
+取值：**0**（默认值，代表性别未知）、**1**（男性）、**2**（女性）。
+        :rtype: int
+        """
         return self._Gender
 
     @Gender.setter
@@ -1739,6 +2088,10 @@ class User(AbstractModel):
 
     @property
     def Age(self):
+        """该字段表示业务用户对应账号的年龄信息。<br>
+取值：**0**（默认值，代表年龄未知）-（**自定义年龄上限**）之间的整数。
+        :rtype: int
+        """
         return self._Age
 
     @Age.setter
@@ -1747,6 +2100,10 @@ class User(AbstractModel):
 
     @property
     def Level(self):
+        """该字段表示业务用户对应账号的等级信息。<br>
+取值：**0**（默认值，代表等级未知）、**1**（等级较低）、**2**（等级中等）、**3**（等级较高），目前**暂不支持自定义等级**。
+        :rtype: int
+        """
         return self._Level
 
     @Level.setter
@@ -1755,6 +2112,10 @@ class User(AbstractModel):
 
     @property
     def Phone(self):
+        """该字段表示业务用户对应账号的手机号信息，支持全球各地区手机号的记录。<br>
+备注：请保持手机号格式的统一，如区号格式（086/+86）等。
+        :rtype: str
+        """
         return self._Phone
 
     @Phone.setter
@@ -1763,6 +2124,9 @@ class User(AbstractModel):
 
     @property
     def Desc(self):
+        """该字段表示业务用户的简介信息，支持汉字、英文及特殊符号，**长度不超过5000个汉字字符**。
+        :rtype: str
+        """
         return self._Desc
 
     @Desc.setter
@@ -1771,6 +2135,9 @@ class User(AbstractModel):
 
     @property
     def HeadUrl(self):
+        """该字段表示业务用户头像图片的访问链接(URL)，支持PNG、JPG、JPEG、BMP、GIF、WEBP格式。<br>备注：头像图片**大小不超过5MB**，建议**分辨率不低于256x256**；图片下载时间限制为3秒，超过则会返回下载超时。
+        :rtype: str
+        """
         return self._HeadUrl
 
     @HeadUrl.setter
